@@ -63,7 +63,7 @@ def inter_p_value(p_value):
 def c_of_c_test(r, n, beta1=0, alpha=.05, precision=4, show=True, option='two-tail', **kwargs):
     """
     two-tail, right, left
-    kwargs needs to contain b1 and std_err if used: 
+    kwargs needs to contain b1 and std_err if used:
     >>> if beta1 != 0:
     >>>    t_value = (kwargs['b1'] - beta1) / kwargs['std_err']
     """
@@ -182,7 +182,15 @@ Prediction interval (confidence interval) for Exact Value: [{lower_bound2:.4f},
     return CI_PI
 
 
-def SimpleLinearRegressionOutlier(Independence=None, Dependence=None, df=None, outlier=True, influential=True, plot=True, display_df=True):
+def SimpleLinearRegressionOutlier(Independence=None, Dependence=None, df=None, outlier=True, influential=True, plot=True, display_df=True, **kwargs):
+    """
+    kwargs: 
+
+    + Pass in xlabel to specify the x label for individual residual plot
+    + pass in s_xlabel to specify the x label for the scatter plot
+    + pass in s_ylabel to specify the y label for the scatter plot
+    """
+
     df_res = smf.ols(f'{Dependence}~ {Independence}', data=df).fit()
     simple_table, data, ss3 = sso.summary_table(df_res, alpha=0.05)
     std_resid = data[:, 10]
@@ -197,6 +205,7 @@ def SimpleLinearRegressionOutlier(Independence=None, Dependence=None, df=None, o
         df_w_std_resid = df_w_std_resid[filter]
         # display(df_w_std_resid)
         return_dict['df_w_std_resid'] = df_w_std_resid
+        return_dict['outlier_filter'] = filter
 
         if display_df:
             print('Outliers:')
@@ -219,9 +228,15 @@ def SimpleLinearRegressionOutlier(Independence=None, Dependence=None, df=None, o
 
             ax.plot((y_id), (sr_id), 'o',
                     ms=circle_rad * 1.5, mec='violet', mfc='none', mew=2)
+        ax.plot([], [], 'o', ms=circle_rad * 0.5, mec='violet',
+                mfc='none', mew=2, label='Outliers')
 
         plt.title('Standardized Residual Plot - Outliers in Violet Circle')
-        plt.xlabel('Predicted Dependent Variable')
+        try:
+            xlabel = kwargs['xlabel']
+        except KeyError:
+            xlabel = f'Predicted {Dependence}'
+        plt.xlabel(xlabel)
         plt.ylabel('Standardized Residual')
 
         return_dict['outlier-fig'] = fig
@@ -246,6 +261,7 @@ def SimpleLinearRegressionOutlier(Independence=None, Dependence=None, df=None, o
         df_w_h = df_w_h[filter]
         return_dict['df_w_h'] = df_w_h
         return_dict['h cv'] = 6 / nobs
+        return_dict['inf_filter'] = filter
 
         if display_df:
             print('Influential Observations:')
@@ -273,11 +289,16 @@ def SimpleLinearRegressionOutlier(Independence=None, Dependence=None, df=None, o
                     ms=circle_rad * 1.5, mec='springgreen', mfc='none', mew=2)
         # ax.set_aspect('equal', adjustable='datalim')
         # ax.add_patch(cir)
+        ax.plot([], [], 'o',
+                ms=circle_rad * 0.5, mec='springgreen', mfc='none', mew=2, label='Influential Observations')
 
         plt.title(
             f'Standardized Residual Plot - Influential Observations ($h_i > {6 / nobs}$) in Spring Green')
-        plt.xlabel(
-            'Predicted Dependent Variable')
+        try:
+            xlabel = kwargs['xlabel']
+        except KeyError:
+            xlabel = f'Predicted {Dependence}'
+        plt.xlabel(xlabel)
         plt.ylabel('Standardized Residual')
         # plt.legend()
         return_dict['inf-fig'] = fig
@@ -308,6 +329,8 @@ def SimpleLinearRegressionOutlier(Independence=None, Dependence=None, df=None, o
 
             ax.plot((x_value), (y_id), 'o',
                     ms=circle_rad * 1.5, mec='violet', mfc='none', mew=2)
+        ax.plot([], [], 'o', ms=circle_rad * 0.5, mec='violet',
+                mfc='none', mew=2, label='Outliers')
     except:
         pass
     try:
@@ -318,14 +341,28 @@ def SimpleLinearRegressionOutlier(Independence=None, Dependence=None, df=None, o
 
             ax.plot((x_value), (y_id), 'o',
                     ms=circle_rad * 1.5, mec='springgreen', mfc='none', mew=2)
+        ax.plot([], [], 'o',
+                ms=circle_rad * 0.5, mec='springgreen', mfc='none', mew=2, label='Influential Observations')
+
     except:
         pass
 
     plt.legend()
 
+    ax.legend(loc='center left', bbox_to_anchor=(
+        1, 0.5), fancybox=True, shadow=True)
+
     plt.title('Scatter Plot')
-    plt.xlabel(Independence)
-    plt.ylabel(Dependence)
+    try:
+        xlabel = kwargs['s_xlabel']
+    except KeyError:
+        xlabel = f'{Independence}'
+    try:
+        ylabel = kwargs['s_ylabel']
+    except KeyError:
+        ylabel = f'{Dependence}'
+    plt.xlabel(xlabel)
+    plt.ylabel(ylabel)
 
     add_margin(ax, x=0.02, y=0.00)  # Call this after tsplot
 
@@ -394,6 +431,7 @@ def SimpleLinearRegression(Independence=None, Dependence=None, df=None, alpha=0.
     results = f"""======= Simple Linear Regression Results =======
 Dep. Variable: {Dependence}
 No. of Observations: {int(df_result.nobs)}
+Mean of Dep. Variable: {np.mean(df[Dependence]):.{precision}f}
 Standard Error: {s_e:.{precision}f}
 SSR: {ssr_value:.{precision}f}
 R-square: {r_square:.{precision}f}
@@ -402,6 +440,7 @@ Estimated model: y = {intercept:.{precision}f} + {slope:.{precision}f} x"""
 
     if test == True:
         results += f"""
+
 **** t-Test of Slope <{s_option}> ****
 t (observed value): {s_t_value:.{precision}f}
 t (critical value): {s_t_critical:.{precision}f}
